import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {NavigationLink} from "../navigation-link-list/navigation-link-list.component";
import {TaskService, TaskTaskgroupInfo} from "../../api";
import {CalendarEvent} from "angular-calendar";
import * as moment from "moment";
import {locale} from "moment";
import {Subject} from "rxjs";

@Component({
  selector: 'app-upcoming-deadlines-overview',
  templateUrl: './upcoming-deadlines-overview.component.html',
  styleUrls: ['./upcoming-deadlines-overview.component.css'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class UpcomingDeadlinesOverviewComponent implements OnInit{
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: "Dashboard",
      routerLink: ['/']
    },
    {
      linkText: "Upcoming Deadlines",
      routerLink: ["/deadlines"]
    }
  ]

  events: CalendarEvent[] = []
  viewDate = new Date()
  refresh: Subject<void> = new Subject<void>()

  constructor(private taskService: TaskService) {
  }


  ngOnInit() {
    this.taskService.tasksAllScopeDetailedGet("UNFINISHED", true).subscribe({
      next: resp => {
        resp.forEach(taskShortInfo => {
          const task_taskgroupInfo = taskShortInfo as TaskTaskgroupInfo
          this.events.push({
            title: task_taskgroupInfo.taskName,
            start: moment(task_taskgroupInfo.deadline).toDate(),
            end: moment(task_taskgroupInfo.deadline).toDate(),
            resizable: {
              beforeStart: false,
              afterEnd: false
            },
            draggable: false,
            allDay: true,
            color: {
              primary: '#1e90ff',
              secondary: '#D1E8FF',
            }
          })
        })
        this.refresh.next()
      }
    })
  }
}
